@@ -1,4 +1,4 @@
-# $Id: Client.pm 109 2009-01-07 01:59:33Z miyagawa $
+# $Id$
 
 package XML::Atom::Client;
 use strict;
@@ -188,7 +188,7 @@ sub munge_response {
     if ($client->use_soap && (my $xml = $res->content)) {
         my $doc;
         if (LIBXML) {
-            my $parser = XML::LibXML->new;
+            my $parser = $client->libxml_parser;
             $doc = $parser->parse_string($xml);
         } else {
             my $xp = XML::XPath->new(xml => $xml);
@@ -218,6 +218,8 @@ sub _utf8_off {
     }
 }
 
+sub libxml_parser { XML::Atom->libxml_parser }
+
 package LWP::UserAgent::AtomClient;
 use strict;
 use Scalar::Util;
